about summary refs log tree commit diff
path: root/src/n-dhcp4
diff options
context:
space:
mode:
authorMichael Biebl <biebl@debian.org>2024-08-09 18:57:26 +0200
committerMichael Biebl <biebl@debian.org>2024-08-09 18:57:26 +0200
commit5ebc16389d33662f712e49a8d5f3445f6b34ca05 (patch)
treeaf14aec1d1271903e73ef2b45d6b9c6d6c188f44 /src/n-dhcp4
parentf07580d7a481ecbc1e90033b7fa5607e0ab2d051 (diff)
parente96d74409128c6a977e31f24fad9b267d2feb9a1 (diff)
Update upstream source from tag 'upstream/1.48.8'
Update to upstream version '1.48.8'
with Debian dir b9f8c1b806c3088cd4a6040531628e5352ccb2ee
Diffstat (limited to 'src/n-dhcp4')
-rw-r--r--src/n-dhcp4/src/util/link.c16
1 files changed, 8 insertions, 8 deletions
diff --git a/src/n-dhcp4/src/util/link.c b/src/n-dhcp4/src/util/link.c
index 54d9a5c3..ec7836d1 100644
--- a/src/n-dhcp4/src/util/link.c
+++ b/src/n-dhcp4/src/util/link.c
@@ -223,28 +223,28 @@ void link_del_ip4(Link *link, const struct in_addr *addr, unsigned int prefix) {
 }
 
 /**
  * link_set_master() - change the bridge master of an interface
  * @link:                       link to operate on
  * @if_master:                  bridge to set as master
  *
  * This sets @if_master as the new master bridge of @link. The specified bridge
  * must be in the same network namespace as @link.
  */
-void link_set_master(Link *link, int if_master) {
+void link_set_controller(Link *link, int if_controller) {
         int oldns;
 
         netns_get(&oldns);
         {
-                char *p, ifname_master[IF_NAMESIZE + 1] = {}, ifname[IF_NAMESIZE + 1] = {};
+                char *p, ifname_controller[IF_NAMESIZE + 1] = {}, ifname[IF_NAMESIZE + 1] = {};
                 int r;
 
                 netns_set(link->netns);
 
                 p = if_indextoname(link->ifindex, ifname);
                 c_assert(p);
-                p = if_indextoname(if_master, ifname_master);
+                p = if_indextoname(if_controller, ifname_controller);
                 c_assert(p);
-                r = asprintf(&p, "ip link set %s master %s", ifname, ifname_master);
+                r = asprintf(&p, "ip link set %s master %s", ifname, ifname_controller);
                 c_assert(r > 0);
                 r = system(p);
                 c_assert(r == 0);
@@ -223,28 +223,28 @@ void link_del_ip4(Link *link, const struct in_addr *addr, unsigned int prefix) {
 
 /**
- * link_set_master() - change the bridge master of an interface
- * @link:                       link to operate on
- * @if_master:                  bridge to set as master
+ * link_set_controller() - change the bridge controller of an interface
+ * @link:                  link to operate on
+ * @if_controller:         bridge to set as controller 
  *
@@ -223,28 +223,28 @@ void link_del_ip4(Link *link, const struct in_addr *addr, unsigned int prefix) {
  *
- * This sets @if_master as the new master bridge of @link. The specified bridge
+ * This sets @if_controller as the new controller bridge of @link. The specified bridge
  * must be in the same network namespace as @link.
  */